@@ -135,7 +135,7 @@ class Client:
                 "GET", f"{self.endpoints.core}/api/v1/batches/{id}/results"
             )["data"]
             for job_data in jobs_data:
-                job_data["result"] = results.get(job_data["id"], None)
+                job_data["result"] = results.get(str(job_data["id"]), None)
         return batch_data, jobs_data
 
     def _get_job(self, job_id: int) -> Dict:
